@@ -1,6 +1,6 @@
 import requests
 from bs4 import BeautifulSoup
-from roulette_russe import Scraper
+from roulette_russe.Scraper import Scraper
 
 
 class Choosemycompany(Scraper):
