@@ -1,7 +1,7 @@
 from urllib.parse import quote
 
 import requests
-from roulette_russe import Scraper
+from roulette_russe.Scraper import Scraper
 
 
 class TwitterScraper(Scraper):
@@ -12,13 +12,13 @@ class TwitterScraper(Scraper):
         super(TwitterScraper, self).__init__(input_config, output_columns, rr)
 
     def get_guest_token(self):
+        self.guest_token_number_of_uses += 1
         if self.guest_token_number_of_uses > 10:
             r = requests.get('https://twitter.com/CNBC', proxies=self.get_proxies(), headers={
                 'User-Agent': 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1'
             })
             self.guest_token_number_of_uses = 1
             self.guest_token = r.text.split('decodeURIComponent("gt=')[1].split(';')[0]
-        print(self.guest_token)
         return self.guest_token
 
     def get_num_id_from_username(self, username):
@@ -77,6 +77,8 @@ class TwitterScraper(Scraper):
                     'retweets_number': tweets[k]['retweet_count'],
                     'likes_number': tweets[k]['favorite_count']
                 })
+            if len(tweets_list) > 1000:
+                return tweets_list
         return tweets_list
 
     def scrap(self):
